function [Simu] = launch_CP_AR_Carlin_Gelman_Smith(y,AR_lags,nb_MCMC,graph)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Function : Estimation of a CP model with 2 regimes using the method 
%%%%% of Carlin, Gelman and Smith. The Marginal log-likelihood is not
%%%%% computed
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Inputs : 
%%%%% y contains the dependent variable (T * 1)
%%%%% AR_lags stands for the order of the AR process in each regime
%%%%% (default = 1)
%%%%% nb_MCMC : number of MCMC iterations (default = 1000)
%%%%% graph : if =1, some convergence graphics are displayed at the end of
%%%%% the simulation (by default = 0)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Outputs :
%%%%% Simu is a structure containing :
%%%%% - post_beta and post_sigma : MCMC Posterior draws of Beta and sigma^2
%%%%% under CP priors
%%%%% - beta_ols and sigma_ols are the OLS results of the starting values.
%%%%% - post_tau : MCMC draws of the break date sampled by Griddy-Gibbs
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if(nargin<4)
    graph = 0;
    if(nargin<3)
        nb_MCMC = 1000;
        if(nargin<2)
            AR_lags = 1;
        end
    end
end
[X y] = AR_explanatory_var(y,AR_lags);
[Simu] = Gibbs_regression_Carlin_Gelman_Smith(y,X,nb_MCMC,graph);